@@ -1,9 +1,10 @@
 package Promises6::Evo::Deferred;
 use Evo::Base 'Promises6::Deferred';
+use Evo;
 
 sub send_msg($self, @args) {
   my $train = $self->builder->train;
-  $train->asap(sub { $self->SUPER::send_msg(@args) });
+  Evo::asap { $self->SUPER::send_msg(@args) };
 }
 
 1;
@@ -22,7 +23,7 @@ Promises6::Evo::Deferred - A deferred class
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 METHODS
 
